/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.util.Enumeration;

import ui.Local;

/**
 * Put a human readable text file into the backup directory
 * with the backup source path, the list of dates of the current
 * backup and whether this backup is finished or not.
 * 
 * @author  Georg Dietrich
 * @version 1.0
 */
public class BackupDescription {
	public BackupDescription (File file, Settings settings) {
		try {

			BufferedWriter writer = new BufferedWriter(new FileWriter(file));
			writer.write("Backup generated by jabak version "+Local.VERSION); writer.newLine();
			writer.write(""); writer.newLine();
			writer.write("this is a backup of the contents of the directory"); writer.newLine();
			writer.write(settings.paths.sourceDir); writer.newLine();
			writer.write(""); writer.newLine();
			writer.write("filtered by the file filters"); writer.newLine();
			writer.write(settings.filterString); writer.newLine();
			writer.write(""); writer.newLine();
			writer.write("this backup is of the type (1 - incremental, 2 - diff2diff, 3 - diff3full, 4 - full)"); writer.newLine();
			writer.write(settings.backupType+""); writer.newLine();
			writer.write(""); writer.newLine();
			writer.write("list of backups this one is dependend of"); writer.newLine();
			writer.write("full:"); writer.newLine();
			for (Enumeration e = settings.dependencies.fullDep.elements(); e.hasMoreElements(); ){
				writer.write((String)e.nextElement()); writer.newLine();
			}
			writer.write("diff:"); writer.newLine();
			for (Enumeration e = settings.dependencies.diffDep.elements(); e.hasMoreElements(); ){
				writer.write((String)e.nextElement()); writer.newLine();
			}
			writer.write("incr:"); writer.newLine();
			for (Enumeration e = settings.dependencies.incrDep.elements(); e.hasMoreElements(); ){
				writer.write((String)e.nextElement()); writer.newLine();
			}
			writer.write(""); writer.newLine();
			writer.write("this backup is"); writer.newLine();
			if (settings.backupFinished) {
				writer.write("complete"); writer.newLine();
				writer.write(""); writer.newLine();
				writer.write("look at the contents of file filelist.zip for a complete"); writer.newLine();
				writer.write("list of files backed at this time"); writer.newLine();
			} else {
				writer.write("not complete"); writer.newLine();
			}
			
			writer.close();

		} catch (Exception e) {
			System.err.println("backup description gescheitert");
			e.printStackTrace();
			throw new RuntimeException();
		}

	}
}
