/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.util.Vector;

/**
 * @author  Georg Dietrich
 * @version 1.3 on 2004-05-15
 * @version 1.2 on 2004-05-05
 * @version 1.1 on 2004-05-03
 * @version 1.0 on 2004-04-09
 */
public class DataFile {

  // TODO: documentation

	/** the data file in the file system */
	protected File file;
	/** the hash values of the last backups, for detecting changes to files */
	public long   incHash, difHash, fulHash;
	/** the modification dates of the last backups, for detecting changes to files */
	public long   incMod,  difMod,  fulMod;
	/** the time stamps of the last backups */
	public String incDate, difDate, fulDate;
	/** the backup history of this file */
	public Vector all = new Vector();
	
	public DataFile (File dataFile) {
		file = dataFile;
		if (dataFile.exists()) {
			try {
				BufferedReader reader = new BufferedReader(new FileReader(dataFile));
				
				if (!reader.readLine().equals("gb_1.1")) { 
					System.err.println("conflicting versions in data file "+dataFile);
					System.err.println("remove all data files and try again.");
					throw new RuntimeException();
				}
				incHash = Util.parseLong(reader.readLine());
				incMod  = Util.parseLong(reader.readLine());
				incDate = reader.readLine();

				difHash = Util.parseLong(reader.readLine());
				difMod  = Util.parseLong(reader.readLine());
				difDate = reader.readLine();

				fulHash = Util.parseLong(reader.readLine());
				fulMod  = Util.parseLong(reader.readLine());
				fulDate = reader.readLine();
				
				reader.readLine();  // "."
				
				for (String read = reader.readLine(); !read.equals("."); read = reader.readLine())
					all.add(read);

				reader.close();
			} catch (Exception e) {
				System.err.println("reading data file failed: "+dataFile);
				e.printStackTrace();
				throw new RuntimeException();
			}
		} else {
			incHash = difHash = fulHash = -1;
			incMod  = difMod  = fulMod  = -1;
			incDate = difDate = fulDate = "";
		}
	}

	public boolean checkState (Settings settings, long hashSum, long modDate) {
		boolean result = false;
		switch (settings.backupType) {
			case 1:
			result |= settings.useDate && (modDate != incMod);
			result |= settings.useHash && (hashSum != incHash);
			break;
			
			case 2:
			result |= settings.useDate && (modDate != difMod);
			result |= settings.useHash && (hashSum != difHash);
			break;
			
			case 3:
			if (settings.dependencies.timeStamps.contains(difDate)) {
				result |= settings.useDate && (modDate != difMod);
				result |= settings.useHash && (hashSum != difHash);
			} else {
				result |= settings.useDate && (modDate != fulMod);
				result |= settings.useHash && (hashSum != fulHash);
			}
			break;
			
			case 4:
			if (settings.dependencies.timeStamps.contains(fulDate)) {
				result |= settings.useDate && (modDate != fulMod);
				result |= settings.useHash && (hashSum != fulHash);
			} else {
				result = true;
			}
			break;
			
			default:
			throw new RuntimeException();
		}
		return result;
	}

	public void save (Settings settings) {
		Util.makeDirs(file);
		try {

			BufferedWriter writer = new BufferedWriter(new FileWriter(file));
			writer.write("gb_1.1"); writer.newLine();

			writer.write(incHash+""); writer.newLine();
			writer.write(incMod +""); writer.newLine();
			writer.write(incDate+""); writer.newLine();

			writer.write(difHash+""); writer.newLine();
			writer.write(difMod +""); writer.newLine();
			writer.write(difDate+""); writer.newLine();

			writer.write(fulHash+""); writer.newLine();
			writer.write(fulMod +""); writer.newLine();
			writer.write(fulDate+""); writer.newLine();

			writer.write("."); writer.newLine();

			writer.write(settings.backupType+""); writer.newLine();
			writer.write(incHash+""); writer.newLine();
			writer.write(incMod +""); writer.newLine();
			writer.write(incDate+""); writer.newLine();
			for (int i=0; i<all.size(); i++) {
				writer.write(all.get(i).toString()); writer.newLine();
			}
			writer.write("."); writer.newLine();

			writer.close();

		} catch (Exception e) {
			System.err.println("save data file gescheitert fr "+file);
			e.printStackTrace();
			throw new RuntimeException();
		}
	}
	
	public void remove () {
		if (file.exists()) file.delete();
	}

}
