/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * @author  Georg Dietrich
 * @version 1.0 on 2004-04-10
 */
public class FileList implements ObjectHandler {

	OutputStreamWriter writer;
	
	public FileList (File file, Settings settings) {
		
		try {
			
			// initiate the zip file writer
			FileOutputStream fileout = new FileOutputStream(file);
			ZipOutputStream  zipout  = new ZipOutputStream (fileout);
			zipout.putNextEntry(new ZipEntry("filelist.txt"));
			writer = new OutputStreamWriter(zipout);

			// write header text
			writer.write("List of all files checked for the backup "+settings.timeStamp+"\n");
			writer.write("\n");
			writer.write("Filter rules used: "+settings.filterString+"\n");
			writer.write("\n");

			// recurse through the files
			Util.recurseDirectoryFilter(new File(settings.paths.sourceDir), this, settings);

			// close zip file writer
			writer.flush();
			zipout.flush();
			zipout.closeEntry();
			zipout.close();
			fileout.flush();
			fileout.close();

		} catch (Exception e) {
			System.err.println ("problem during writing filelist");
			e.printStackTrace();
			throw new RuntimeException();
		}

	}

	public boolean perform(Object object) {
		try {
			writer.write(object.toString()+"\n");
			return true;
		} catch (IOException e) {
			System.err.println ("problem during writing filelist");
			e.printStackTrace();
			throw new RuntimeException();
		}
	}

}
