/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.io.File;

import ui.GuiSettings;

/**
 * @author  Georg Dietrich
 * @version 1.0 on 02.05.2004
 */
public class Paths {

	/** the source directory of the backup */
	public String sourceDir;
	/** the directory where backups are collected in */
	public String backupRoot;
	/** the directory that contains this single backup (the time stamp subdirectory) */
	public String backupDir;
	/** the directroy the backup zip files themselves are stored in */
	public String backupTarget;
	/** the path of the backup description file */
	public String backupDesc;
	/** the path of the backup file list path */
	public String backupList;
	/** the directory to write the backup data into, including source localisation stamp */
	public String dataDir;
	/** the path of the backup data description file */
	public String dataDesc;

	/**
	 * initialize the paths with settings taken from the GUI
	 */
	public Paths(GuiSettings guiSettings) {
		// copy the source path
		sourceDir = Util.canonicalPath (guiSettings.sourceDir);

		// copy the data root path and make it a directory path
		dataDir  = Util.canonicalPath (guiSettings.dataDir) + File.separator;
		// add source localisation stamp, replacing non-word-chars by "_"
		dataDir += sourceDir.replaceAll("\\W","_").replaceAll("__","_");

		// initialize the data description file path
		dataDesc = dataDir + File.separator + ".backup";

		// copy the backup root path
		backupRoot = Util.canonicalPath (guiSettings.backupDir);
	}

	/**
	 * initialize backupDir and backupDesc with the time stamp
	 * 
	 * @param timeStamp  the time stamp of the current backup
	 */
	public void adaptBackupPath (String timeStamp) {
		// add time stamp to root
		backupDir = backupRoot + File.separator + timeStamp;
		// initialize final backup path
		backupTarget = backupDir + File.separator + "backup";
		// initialize backup description file path
		backupDesc = backupDir + File.separator + "readme.txt";
		// initialize filelist file path
		backupList = backupDir + File.separator + "filelist.zip";
	}
}
