/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

/**
 * Class enabling a simple progress output to System.out as well as a more
 * sophisticated progress output through a derived class by the GUI.
 * 
 * @author  Georg Dietrich
 * @version 1.2 on 2004-05-05
 * @version 1.1 on 2004-04-18
 * @version 1.0 on 2004-04-11
 */
public abstract class ProgressInterface {

	/**
	 * the level of messages to display and log.
	 * 
	 * -1 - nothing
	 *  0 - only errors
	 *  1 - and warnings
	 *  2 - and progress
	 *  3 - and skipped files
	 *  4 - really everything
	 */
	protected int displayLevel;

	/** constructor */
	public ProgressInterface (int newDisplayLevel) { displayLevel = newDisplayLevel; }

	/** extract all necessary information out of the settings object. */
	public void display (Settings settings) {
		display(settings.currentSize, settings.backupSize, settings.filesBackedUp, settings.filesSkipped);
	}

	/** forwared progress information to System.out. overwritten by the GUI progressInterface. */
	public void display (long size, long sizeMax, int numFiles, int skipFiles) {
		log (numFiles+": "+size+" of "+sizeMax+".  "+skipFiles+" skipped.", 4);
	}

	/** print messages. overwritten by the GUI progressInterface. */
	public void log (String string, int level) {
		if (level == 0) { System.err.println(string); return;	}
		if (level <= displayLevel) System.out.println (string);
	}
}
