/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package backup;

import java.util.Vector;


/**
 * settings used by the core for processing a backup request
 * 
 * @author  Georg Dietrich
 * @version 1.3 on 2004-05-02
 * @version 1.2 on 2004-04-18
 * @version 1.1 on 2004-04-10
 * @version 1.0 on 2004-04-09
 */
public class Settings {
	
	/** the progress interface for displaying progress */
	public ProgressInterface log;
	
	/** all file paths used for the current backup */
	public Paths paths;
	
	/** original filter string, used for writing it into human readable description files */
	public String filterString;

	/** file filters for choosing the backup files */
	public Vector fileFilters = new Vector();
	
	/** flag whether the filters work positively or negatively */
	public boolean filterOut = true;

	/** flag whether to use hash comparision */
	public boolean useHash = false;
	
	/** flag whether to use modification date comparision */
	public boolean useDate = false;
	
	/** file filters for zip compression */
	public Vector zipFilters = new Vector();
	
	/** zip compression values belonging to the zip file filters */
	public Vector zipValues = new Vector();
	
	/** default zip compression value for files not filtered */
	public int defaultZipValue;

	/** dependencies from backups performed before */
	public Dependencies dependencies;

	/** the size in bytes to use (approx) for one backup */
	public long backupSize;

	/** the time stamp of this backup, to be used in backup path */
	public String timeStamp;

	/** the type of backup to perform: 1/2/3/4 incremental/diff2diff/diff2full/full */
	public int backupType;

	/** the current size of the backup in bytes */
	public long currentSize = 0;

	/** the tolerance factor for the backup size */
	// TODO: make this value configurable
	public double sizeTolerance = 1.03; // 3%

	/** flag whether all data could be backuped within the limits of the backup size */
	public boolean backupFinished = true;

	/** counter for files backed up */
	public int filesBackedUp = 0;
	
	/** counter for files skipped because they are already backed up */
	public int filesSkipped = 0;
	
}
