/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import javax.swing.JButton;
import javax.swing.JFileChooser;

/**
 * DirChooserButton is a JButton that opens a directory chooser dialog
 * and feeds the result into the text field of a JTextField.
 * 
 * @author Georg Dietrich
 * @version 1.2 on 2004-05-16
 * @version 1.0 on 25.04.2004
 */
class DirChooserButton extends JButton {

	/**
	 * constructor for the button
	 * 
	 * @param title        the text to display in the button
	 * @param directory    the StringContainer to store the chosen dir in
	 */
	DirChooserButton (String title, final StringContainer directory) {
		// construct the button
		super(title);
		// action listener for pressing the button
		addActionListener(new java.awt.event.ActionListener() { 
			public void actionPerformed(java.awt.event.ActionEvent e) {
				// display a file chooser that accepts only dirs
				JFileChooser fc = new JFileChooser(directory.getString());
				fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
				// open the file chooser
				int returnVal = fc.showOpenDialog(null);
				// check whether "OK" or "CANCEL" was pressed
				if (returnVal == JFileChooser.APPROVE_OPTION) {
					// feed the directory chosen file into the StringContainer
					directory.setString(fc.getSelectedFile().toString());
				}
			}
		});
	}
}
