/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import java.io.BufferedWriter;
import java.io.File;
import java.io.IOException;

/**
 * utility class wrapping BufferedWriter handling all exceptions
 * 
 * @author  Georg Dietrich
 * @version 1.1 on 2004-05-16
 * @version 1.0 on 2004-04-20
 */
public class FileWriter {

	// TODO: look for overlapping functionality with backup.util

	/** the base BufferedWriter */
	protected BufferedWriter writer = null;

	/**
	 * construct a FileWriter out of a file path string
	 * 
	 * @param string  the file path string of the file to be written
	 */
	public FileWriter(String string) {
		this(new File(string));
	}

	/**
	 * construct a FileWriter out of a file
	 * 
	 * @param file  the file to be written
	 */
	public FileWriter(File file) {
		try {
			writer = new BufferedWriter(new java.io.FileWriter(file));
		} catch (IOException e) {
			Log.println("Error on opening FileWriter "+file);
			Log.println(e.toString());
			Log.println("");
		}
	}

	/**
	 * write a string as a line to the writer
	 * 
	 * @param string  the string to write
	 */	
	public void println(String string) {
		if (writer == null) return;
		try {
			writer.write(string);
			writer.newLine();
		} catch (IOException e) {
			Log.printlnNoFile("Error on writing String to FileWriter: "+string);
			Log.printlnNoFile(e.toString());
			Log.printlnNoFile("");
		}
	}

	// TODO: implement close method - cleaner code

	/**
	 * flush and close, if the fileWriter is no more needed
	 */	
	protected void finalize() throws Throwable {
		if (writer != null) {
			writer.flush();
			writer.close();
		} 
		super.finalize();
	}
}
