/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import java.util.Arrays;
import java.util.Enumeration;
import java.util.Vector;

import backup.Util;

/**
 * Settings set within the GUI which are used in the backup core.
 * 
 * @author  Georg Dietrich
 * version 1.2 on 2004-04-29
 * @version 1.0 on 2004-04-12
 */
public class GuiSettings {
	
	/** the source directory path */
	public StringContainer sourceDir = new StringContainer();

	/** the backup root directory path */
	public StringContainer backupDir = new StringContainer();
	
	/** the data root directory path */
	public StringContainer dataDir = new StringContainer();
	
	/** the maximum size in megabytes string */
	public StringContainer size = new StringContainer();

	/** the type of backup to perform */
	public StringContainer backupType = new StringContainer();
	
	/** the file filters to apply during the backup */
	public StringContainer filters = new StringContainer();

	/** whether to use hash values, date or both for comparision */ 
	/* TODO: check whether implemented everywhere */
	public StringContainer compare = new StringContainer();

	/** flag whether to try to start backup without user interaction */
	public boolean immediateStart = false;

	/** flag whether not to build a GUI */
	public boolean noGui = false;

	/** the filters to use for determining zip compression */
	public StringContainer zipFilters = new StringContainer();

	/** the result string or help-file of the backup process */
	public Object result;

	/** the progress output interface to the core */
	// TODO: make command line switch and gui setter
	public ProgressInterface log;

	/** constructor */
	public GuiSettings (String[] args) {
		SettingsParser.parseSettings(args, this);
	}
	
	/** gets called each time the settings are changed by the GUI */
	public static void changed() {
	}
	
	/**
	 * check the current settings for consistency
	 * 
	 * @return  true if backup is possible with settings
	 */
	public boolean check() {

		// TODO: implement fitting help comments
		if (!Rule.DIRECTORY.check(sourceDir)) return false;
		if (!Rule.DIRECTORY.check(backupDir)) return false;
		if (!Rule.DIRECTORY.check(dataDir)) return false;
		if (Util.parseInt(backupType) == 0) return false;
		if (Util.parseInt(size) == 0) return false;
		// TODO: fill the filterV field
		return filterCheck();
	}

	/**
	 * check the current filters for validity
	 * TODO: move to rules
	 * 
	 * @return  true if valid
	 */
	boolean filterCheck() { return filterCheck(filters.toString()); }

	/**
	 * check a set of filters for validity
	 * TODO: move to rules
	 * 
	 * @return  true if valid
	 */
	static boolean filterCheck(String filters) {

		// check for default setting "all"
		if (filters.equals("all")) { return true; }

		try {

			// split filters into vector
			Vector v = new Vector(Arrays.asList(filters.split(" ")));
			
			// check whether all filters are valid regular expressions
			for (Enumeration e = v.elements(); e.hasMoreElements(); ) {
				"test.string".matches(e.nextElement().toString());
			}

			// filters are alright
			return true;
						
		} catch (Exception e) {
			// filters are not alright
			return false;
		}
	}
	
	boolean zipFilterCheck() {
		// TODO: implement
		return true;
	}

	static boolean zipFilterCheck(String filters) {
		// TODO: implement and move to rules
		return true;
	}

}
