/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import javax.swing.JProgressBar;
import javax.swing.SwingUtilities;

/**
 * Extension of the ProgressInterface of the backup core
 * to display progress within the ui.
 * 
 * @author  Georg Dietrich
 * @version 1.2 on 2004-04-18
 * @version 1.1 on 2004-04-14
 * @version 1.0 on 2004-04-11
 */
public class ProgressInterface extends backup.ProgressInterface {

	/** the base JProgressBar */
	protected JProgressBar jProgressBar;

	/**
	 * constructor: save the progress bar object for further reference
	 * 
	 * @param bar  the progress bar to use
	 */
	public ProgressInterface (JProgressBar bar, int displayLevel) {
		super(displayLevel);
		jProgressBar = bar;
	}

	/**
	 * update the progress bar with new numbers
	 */
	public void display(final long size, final long sizeMax, final int numFiles, final int skipFiles) {

		// construct a runnable out of the update code
		Runnable updateCode = new Runnable() {
			public void run() {
				// update the percentile value of the progress bar
				// float used to avoid overflows
				jProgressBar.setValue((int)((float)size*100/sizeMax));
				// update the string displayed in the progress bar
				jProgressBar.setString(skipFiles + " skipped / "+numFiles+" backed up");
			}
		};
		
		// execute the runnable within the GUI thread
		SwingUtilities.invokeLater(updateCode);
		
		// call the core method for printing to system.out
		super.display(size, sizeMax, numFiles, skipFiles);
	}

	public void log (String string, int level) {
		if (level <= displayLevel) Log.println (string);
//		super.log(string, level);
	}
}
