/*
 * jabak Java Backup
 * 
 * Copyright (C) under the terms of the GNU General Public License
 * as explained in the file "disclaimer.txt"
 */

package ui;

import java.awt.Font;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;

import javax.swing.BoxLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;

/**
 * this class represents an own frame displaying text
 * either from a string or from a file.
 * 
 * @author  Georg Dietrich
 * @version 1.1 on 2004-04-14
 * @version 1.0 on 2004-04-11
 */
public class TextFrame extends JFrame {

	JTextArea textArea;
	JScrollPane scrollPane;
	
	public TextFrame (String title, Object contents) {
		if (contents.getClass().isInstance(new String())) {
			textFrame(title,(String)contents);
		} else {
			textFrame(title,(File)contents);
		}
	}

	/**
	 * create a text frame from a text file
	 * 
	 * @param title     the title of the text frame
	 * @param contents  the file to read the contents from
	 */
	protected void textFrame (String title, File contents) {

		// first store all text from file into a string.
		// this causes the text frame to initially display
		// the head of the text instead of the bottom.
		String sum = "";
		try {
			BufferedReader reader = new BufferedReader(new FileReader(contents));
			for (String string = reader.readLine(); string != null; string = reader.readLine())	{
				sum += string+"\n";
			}
			reader.close();
		} catch (Exception e) {
			System.err.println("TextFrame from file failed for "+contents);
			e.printStackTrace();
			throw new RuntimeException();
		}

		// then create the frame with layout and contents
		make (title,sum);
	}

	/**
	 * create a text frame from a string
	 * 
	 * @param title     the title of the frame
	 * @param contents  the frame's contents
	 */	
	protected void textFrame (String title, String contents) {
		make (title,contents);
	}

	/**
	 * set up the text frame
	 * 
	 * @param title     the title of the frame
	 * @param contents  the frame's contents
	 */	
	public void make (String title, String contents) {

		// Create a text area.
		textArea = new JTextArea(contents);
		textArea.setEditable(false);
		textArea.setFont(new Font("Courier", Font.ITALIC, 16));
		textArea.setLineWrap(true);
		textArea.setWrapStyleWord(true);
		
		// embed the text area into a scroll pane
		scrollPane = new JScrollPane(textArea);
		scrollPane.setVerticalScrollBarPolicy(
						JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);

		// embed the scroll pane into a content pane
		JPanel pane = new JPanel();
		BoxLayout layout = new BoxLayout(pane, BoxLayout.Y_AXIS);
		pane.setLayout(layout);
		pane.add(scrollPane);
		
		// embed the content pane in the frame and set up the frame
		this.setSize(700, 200);
		this.setContentPane(pane);
		this.setTitle(title);
		this.setVisible(true);
	}
}
